Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(160)

Unified Diff: ui/views/animation/test/test_ink_drop_host.h

Issue 1937103003: Rename of InkDropAnimation classes to InkDropRipple. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Removed test_ink_drop_animation_observer.h from views.gyp and doc update. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/animation/test/test_ink_drop_host.h
diff --git a/ui/views/animation/test/test_ink_drop_host.h b/ui/views/animation/test/test_ink_drop_host.h
index 7bb18e1a17af9ae3386618a7a54d38ce3f677ea5..9379c5d0039037f5e16c0f20b700643142928f76 100644
--- a/ui/views/animation/test/test_ink_drop_host.h
+++ b/ui/views/animation/test/test_ink_drop_host.h
@@ -30,7 +30,7 @@ class TestInkDropHost : public InkDropHost {
// TestInkDropHost:
void AddInkDropLayer(ui::Layer* ink_drop_layer) override;
void RemoveInkDropLayer(ui::Layer* ink_drop_layer) override;
- std::unique_ptr<InkDropAnimation> CreateInkDropAnimation() const override;
+ std::unique_ptr<InkDropRipple> CreateInkDropRipple() const override;
std::unique_ptr<InkDropHover> CreateInkDropHover() const override;
private:
@@ -38,7 +38,7 @@ class TestInkDropHost : public InkDropHost {
bool should_show_hover_;
// When true, the InkDropAnimation/InkDropHover instances will have their
// timers disabled after creation.
bool disable_timers_for_test_;
« no previous file with comments | « ui/views/animation/test/test_ink_drop_animation_observer_helper.h ('k') | ui/views/animation/test/test_ink_drop_host.cc » ('j') | no next file with comments »
@@ -38,7 +38,7 @@ class TestInkDropHost : public InkDropHost {
bool should_show_hover_;
- // When true, the InkDropAnimation/InkDropHover instances will have their
+ // When true, the InkDropRipple/InkDropHover instances will have their
// timers disabled after creation.
bool disable_timers_for_test_;

Powered by Google App Engine
This is Rietveld 408576698